import { API as API$1 } from "../../../scw/api.js";
import { validatePathParam, urlParams } from "../../../helpers/marshalling.js";
import "../../../vendor/base64/index.js";
import { enrichForPagination } from "../../../scw/fetch/resource-paginator.js";
import { marshalCreateJobDefinitionRequest, unmarshalJobDefinition, unmarshalListJobDefinitionsResponse, marshalUpdateJobDefinitionRequest, marshalStartJobDefinitionRequest, unmarshalStartJobDefinitionResponse, marshalCreateJobDefinitionSecretsRequest, unmarshalCreateJobDefinitionSecretsResponse, unmarshalSecret, unmarshalListJobDefinitionSecretsResponse, marshalUpdateJobDefinitionSecretRequest, unmarshalJobRun, unmarshalListJobRunsResponse, unmarshalListJobsResourcesResponse, unmarshalJobsLimits } from "./marshalling.gen.js";
const jsonContentHeaders = {
  "Content-Type": "application/json; charset=utf-8"
};
class API extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = ["fr-par", "nl-ams", "pl-waw"];
  /**
   * Create a new job definition in a specified Project.
   *
   * @param request - The request {@link CreateJobDefinitionRequest}
   * @returns A Promise of JobDefinition
   */
  createJobDefinition = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateJobDefinitionRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions`
    },
    unmarshalJobDefinition
  );
  /**
   * Get a job definition by its unique identifier.
   *
   * @param request - The request {@link GetJobDefinitionRequest}
   * @returns A Promise of JobDefinition
   */
  getJobDefinition = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}`
    },
    unmarshalJobDefinition
  );
  pageOfListJobDefinitions = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions`,
      urlParams: urlParams(
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListJobDefinitionsResponse
  );
  /**
   * List all your job definitions with filters.
   *
   * @param request - The request {@link ListJobDefinitionsRequest}
   * @returns A Promise of ListJobDefinitionsResponse
   */
  listJobDefinitions = (request = {}) => enrichForPagination(
    "jobDefinitions",
    this.pageOfListJobDefinitions,
    request
  );
  /**
   * Update an existing job definition associated with the specified unique
   * identifier.
   *
   * @param request - The request {@link UpdateJobDefinitionRequest}
   * @returns A Promise of JobDefinition
   */
  updateJobDefinition = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateJobDefinitionRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}`
    },
    unmarshalJobDefinition
  );
  /**
   * Delete an exsisting job definition by its unique identifier.
   *
   * @param request - The request {@link DeleteJobDefinitionRequest}
   */
  deleteJobDefinition = (request) => this.client.fetch({
    method: "DELETE",
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}`
  });
  /**
   * Run an existing job definition by its unique identifier. This will create a
   * new job run.
   *
   * @param request - The request {@link StartJobDefinitionRequest}
   * @returns A Promise of StartJobDefinitionResponse
   */
  startJobDefinition = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalStartJobDefinitionRequest(request, this.client.settings)
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}/start`
    },
    unmarshalStartJobDefinitionResponse
  );
  /**
   * Create a secret reference within a job definition.
   *
   * @param request - The request {@link CreateJobDefinitionSecretsRequest}
   * @returns A Promise of CreateJobDefinitionSecretsResponse
   */
  createJobDefinitionSecrets = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalCreateJobDefinitionSecretsRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "POST",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}/secrets`
    },
    unmarshalCreateJobDefinitionSecretsResponse
  );
  /**
   * Get a secret references within a job definition.
   *
   * @param request - The request {@link GetJobDefinitionSecretRequest}
   * @returns A Promise of Secret
   */
  getJobDefinitionSecret = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}/secrets/${validatePathParam("secretId", request.secretId)}`
    },
    unmarshalSecret
  );
  /**
   * List secrets references within a job definition.
   *
   * @param request - The request {@link ListJobDefinitionSecretsRequest}
   * @returns A Promise of ListJobDefinitionSecretsResponse
   */
  listJobDefinitionSecrets = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}/secrets`
    },
    unmarshalListJobDefinitionSecretsResponse
  );
  /**
   * Update a secret reference within a job definition.
   *
   * @param request - The request {@link UpdateJobDefinitionSecretRequest}
   * @returns A Promise of Secret
   */
  updateJobDefinitionSecret = (request) => this.client.fetch(
    {
      body: JSON.stringify(
        marshalUpdateJobDefinitionSecretRequest(
          request,
          this.client.settings
        )
      ),
      headers: jsonContentHeaders,
      method: "PATCH",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}/secrets/${validatePathParam("secretId", request.secretId)}`
    },
    unmarshalSecret
  );
  /**
   * Delete a secret reference within a job definition.
   *
   * @param request - The request {@link DeleteJobDefinitionSecretRequest}
   */
  deleteJobDefinitionSecret = (request) => this.client.fetch({
    method: "DELETE",
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam("jobDefinitionId", request.jobDefinitionId)}/secrets/${validatePathParam("secretId", request.secretId)}`
  });
  /**
   * Get a job run by its unique identifier.
   *
   * @param request - The request {@link GetJobRunRequest}
   * @returns A Promise of JobRun
   */
  getJobRun = (request) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-runs/${validatePathParam("jobRunId", request.jobRunId)}`
    },
    unmarshalJobRun
  );
  /**
   * Stop a job run by its unique identifier.
   *
   * @param request - The request {@link StopJobRunRequest}
   * @returns A Promise of JobRun
   */
  stopJobRun = (request) => this.client.fetch(
    {
      body: "{}",
      headers: jsonContentHeaders,
      method: "POST",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-runs/${validatePathParam("jobRunId", request.jobRunId)}/stop`
    },
    unmarshalJobRun
  );
  pageOfListJobRuns = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/job-runs`,
      urlParams: urlParams(
        ["job_definition_id", request.jobDefinitionId],
        ["order_by", request.orderBy],
        ["organization_id", request.organizationId],
        ["page", request.page],
        [
          "page_size",
          request.pageSize ?? this.client.settings.defaultPageSize
        ],
        ["project_id", request.projectId]
      )
    },
    unmarshalListJobRunsResponse
  );
  /**
   * List all job runs with filters.
   *
   * @param request - The request {@link ListJobRunsRequest}
   * @returns A Promise of ListJobRunsResponse
   */
  listJobRuns = (request = {}) => enrichForPagination("jobRuns", this.pageOfListJobRuns, request);
  /**
   * List jobs resources for the console.
   *
   * @param request - The request {@link ListJobsResourcesRequest}
   * @returns A Promise of ListJobsResourcesResponse
   */
  listJobsResources = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/jobs-resources`
    },
    unmarshalListJobsResourcesResponse
  );
  /**
   * Get jobs limits for the console.
   *
   * @param request - The request {@link GetJobsLimitsRequest}
   * @returns A Promise of JobsLimits
   */
  getJobsLimits = (request = {}) => this.client.fetch(
    {
      method: "GET",
      path: `/serverless-jobs/v1alpha1/regions/${validatePathParam("region", request.region ?? this.client.settings.defaultRegion)}/jobs-limits`
    },
    unmarshalJobsLimits
  );
}
export {
  API
};
